@@ -19,8 +19,8 @@ class Formatter(BaseFormatter):
 
     def format(self, error: Violation) -> str:
         return (
-            f'{error.filename}:{error.line_number}:{error.column_number}'
-            f': {error.code} {error.text}'
+            f"{error.filename}:{error.line_number}:{error.column_number}"
+            f": {error.code} {error.text}"
         )
 
     def write(self, line: str, source: str):
@@ -33,18 +33,18 @@ class Flake8Linter(Linter):
 
         self.app = Application()
         args = [
-            '--isolated',
-            '--max-line-length',
+            "--isolated",
+            "--max-line-length",
             str(config.line_length),
-            '--import-order-style',
-            'pep8',
-            '--ignore',
-            'E203,W503',
+            "--import-order-style",
+            "pep8",
+            "--ignore",
+            "E203,W503",
         ]
         if config.exclude:
-            args.extend(['--extend-exclude', config.exclude])
+            args.extend(["--extend-exclude", config.exclude])
         if config.application_import_names:
-            args.extend(['--application-import-names', config.application_import_names])
+            args.extend(["--application-import-names", config.application_import_names])
 
         prelim_opts, remaining_args = self.app.parse_preliminary_options(args)
 
@@ -68,10 +68,10 @@ class Flake8Linter(Linter):
         return Formatter.errors
 
     def dump_config(self, dst: Path) -> None:
-        with open(dst / '.flake8', 'w') as out:
-            out.write('[flake8]\n')
-            out.write(f'max-line-length = {self.app.options.max_line_length}\n')
-            out.write(f'import-order-style = {self.app.options.import_order_style}\n')
+        with open(dst / ".flake8", "w") as out:
+            out.write("[flake8]\n")
+            out.write(f"max-line-length = {self.app.options.max_line_length}\n")
+            out.write(f"import-order-style = {self.app.options.import_order_style}\n")
             out.write(f'ignore = {",".join(self.app.options.ignore)}\n')
             if self.app.options.extend_exclude:
                 out.write(
@@ -79,10 +79,10 @@ class Flake8Linter(Linter):
                 )
             if self.app.options.application_import_names:
                 out.write(
-                    'application-import-names = '
+                    "application-import-names = "
                     f'{",".join(self.app.options.application_import_names)}\n'
                 )
 
     @property
     def name(self):
-        return 'flake8'
+        return "flake8"
